@@ -1,8 +1,6 @@
 package Text::Handlebars;
-BEGIN {
-  $Text::Handlebars::AUTHORITY = 'cpan:DOY';
-}
-$Text::Handlebars::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Text::Handlebars::VERSION = '0.05';
 use strict;
 use warnings;
 # ABSTRACT: http://handlebarsjs.com/ for Text::Xslate
@@ -151,7 +149,7 @@ Text::Handlebars - http://handlebarsjs.com/ for Text::Xslate
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -304,7 +302,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
