@@ -1,8 +1,6 @@
 package Text::Handlebars::Compiler;
-BEGIN {
-  $Text::Handlebars::Compiler::AUTHORITY = 'cpan:DOY';
-}
-$Text::Handlebars::Compiler::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Text::Handlebars::Compiler::VERSION = '0.05';
 use Mouse;
 
 extends 'Text::Xslate::Compiler';
