@@ -1,8 +1,6 @@
 package Text::Handlebars::Symbol;
-BEGIN {
-  $Text::Handlebars::Symbol::AUTHORITY = 'cpan:DOY';
-}
-$Text::Handlebars::Symbol::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Text::Handlebars::Symbol::VERSION = '0.05';
 use Mouse;
 
 extends 'Text::Xslate::Symbol';
