@@ -1,8 +1,6 @@
 package Text::Xslate::Syntax::Handlebars;
-BEGIN {
-  $Text::Xslate::Syntax::Handlebars::AUTHORITY = 'cpan:DOY';
-}
-$Text::Xslate::Syntax::Handlebars::VERSION = '0.04';
+our $AUTHORITY = 'cpan:DOY';
+$Text::Xslate::Syntax::Handlebars::VERSION = '0.05';
 use Mouse;
 
 use Carp 'confess';
@@ -109,7 +107,12 @@ sub split_tags {
                     }
                 }
                 if (@raw_text) {
-                    $raw_text[-1] .= $tag_start . $code . $tag_end;
+                    if ($close_tag eq '}}}') {
+                        $raw_text[-1] .= '{{{' . $code . '}}}';
+                    }
+                    else {
+                        $raw_text[-1] .= $tag_start . $code . $tag_end;
+                    }
                 }
                 if ($code =~ m{^[#^]} || $code eq 'else') {
                     push @raw_text, '';
